@@ -1,7 +1,7 @@
 #!/opt/local/Library/Frameworks/Python.framework/Versions/3.13/bin/python3.13
 
 """
-Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
@@ -395,12 +395,15 @@ def processResponse(page, responseHeaders, code=None, status=None):
 
         with kb.locks.identYwaf:
             identYwaf.non_blind.clear()
-            if identYwaf.non_blind_check(rawResponse, silent=True):
-                for waf in set(identYwaf.non_blind):
-                    if waf not in kb.identifiedWafs:
-                        kb.identifiedWafs.add(waf)
-                        errMsg = "WAF/IPS identified as '%s'" % identYwaf.format_name(waf)
-                        singleTimeLogMessage(errMsg, logging.CRITICAL)
+            try:
+                if identYwaf.non_blind_check(rawResponse, silent=True):
+                    for waf in set(identYwaf.non_blind):
+                        if waf not in kb.identifiedWafs:
+                            kb.identifiedWafs.add(waf)
+                            errMsg = "WAF/IPS identified as '%s'" % identYwaf.format_name(waf)
+                            singleTimeLogMessage(errMsg, logging.CRITICAL)
+            except Exception as ex:
+                singleTimeWarnMessage("internal error occurred in WAF/IPS detection ('%s')" % getSafeExString(ex))
 
     if kb.originalPage is None:
         for regex in (EVENTVALIDATION_REGEX, VIEWSTATE_REGEX):
